@@ -1,12 +1,14 @@
 import os
-import os.path
-from .core.utils import module as module_utils, library_parameters  #@UnresolvedImport
+from .core.utils import module as module_utils
+from .core.utils import library_parameters
+from .core.utils.library_parameters import library_parameters as par, temp_library_parameters as temp_par
 
 from .core import *
 
 _load_path=os.path.abspath(os.curdir)
 
-par=library_parameters.LibraryParametersStorage(__name__)
+__version__=module_utils.get_package_version("pylablib") or module_utils.get_package_version("pylablib-lightweight")
+
 def reload_all(from_load_path=True, keep_parameters=True):
     """
     Reload all loaded modules.
@@ -14,7 +16,7 @@ def reload_all(from_load_path=True, keep_parameters=True):
     If ``keep_parameters==True``, keep the current library parameters (``pylablib.par``); otherwise, reset them to default.
     """
     if keep_parameters:
-        old_par=par[""].as_dict("flat")
+        old_par=library_parameters.library_parameters.as_dict("flat")
     if from_load_path:
         cur_dir=os.path.abspath(os.curdir)
         os.chdir(_load_path)
@@ -24,13 +26,8 @@ def reload_all(from_load_path=True, keep_parameters=True):
             os.chdir(cur_dir)
     else:
         module_utils.reload_package_modules(__name__)
-    par.refresh()
     if keep_parameters:
-        for k,v in old_par.items():
-            try:
-                par[k]=v
-            except KeyError:
-                pass
+        library_parameters.library_parameters[""]=old_par
 
 def unload_all():
     """
